@@ -1,10 +1,13 @@
 """Generic data model for configuration attributes."""
-from typing import Any, Optional
+from typing import TYPE_CHECKING, Iterable, Mapping
 
 from pydantic import BaseModel, Field
 
+if TYPE_CHECKING:
+    from typing import Any, Optional, Union
 
-class AttrDict(BaseModel):
+
+class AttrDict(BaseModel, Mapping):
     """An object whose attributes can also be accessed through
     subscription, like with a dictionary."""
 
@@ -13,7 +16,7 @@ class AttrDict(BaseModel):
 
         extra = "allow"
 
-    def __contains__(self, name: Any) -> bool:
+    def __contains__(self, name: "Any") -> bool:
         """Enable using the 'in' operator on this object."""
         return self.__dict__.__contains__(name)
 
@@ -27,13 +30,13 @@ class AttrDict(BaseModel):
         else:
             raise KeyError(key)
 
-    def __getitem__(self, key: str) -> Any:
+    def __getitem__(self, key: str) -> "Any":
         """Enable read access through subscription."""
         if key in dir(self):
             return getattr(self, key)
         raise KeyError(key)
 
-    def __setattr__(self, name: str, value: Any) -> None:
+    def __setattr__(self, name: str, value: "Any") -> None:
         """Extend BaseModel.__setattr__ with type-checking."""
         if name in self.__dict__ and self.__dict__[name]:
             target_type = type(self.__dict__[name])
@@ -43,7 +46,7 @@ class AttrDict(BaseModel):
                 )
         super().__setattr__(name, value)
 
-    def __setitem__(self, key: str, value: Any) -> None:
+    def __setitem__(self, key: str, value: "Any") -> None:
         """Enable write access through subscription."""
         self.__setattr__(key, value)
 
@@ -67,21 +70,40 @@ class AttrDict(BaseModel):
         """Return a view of all values."""
         return self.__dict__.values()
 
-    def get(self, key: str, default: Optional[Any] = None) -> Any:
+    def get(self, key: str, default: "Optional[Any]" = None) -> "Any":
         """Mapping `get`-method."""
         return self.__dict__.get(key, default)
 
-    def __ne__(self, other: Any) -> bool:
+    def __ne__(self, other: "Any") -> bool:
         if isinstance(other, BaseModel):
             return self.dict() != other.dict()
         return self.dict() != other
 
+    def update(
+        self, other: "Optional[Union[dict, AttrDict, Iterable[Any]]]" = None, **kwargs
+    ) -> None:
+        """MutableMapping `update`-method."""
+        if other and isinstance(other, (dict, self.__class__)):
+            for key, value in other.items():
+                setattr(self, key, value)
+        elif other and isinstance(other, Iterable):
+            for entry in other:
+                if not len(entry) == 2:
+                    raise ValueError(
+                        "`other` must be an iterable of objects of length two."
+                    )
+            for key, value in other:
+                setattr(self, key, value)
+        if kwargs:
+            for key, value in kwargs.items():
+                setattr(self, key, value)
+
 
 class GenericConfig(BaseModel):
     """Generic class for configuration objects."""
 
-    configuration: Optional[AttrDict] = Field(
-        None,
+    configuration: AttrDict = Field(
+        AttrDict(),
         description="Model-specific configuration options which can either "
         "be given as key/value-pairs or set as attributes.",
     )
