@@ -19,7 +19,7 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:  # pragma: no cover
     from importlib.metadata import EntryPoint
-    from typing import Any, Iterable, Iterator, Optional, Set, Tuple, Type, Union
+    from typing import Any, Iterator, Optional, Set, Tuple, Type, Union
 
     from oteapi.interfaces import IStrategy
 
@@ -307,7 +307,7 @@ class EntryPointStrategyCollection(abc.Collection):
         """Add entry points to the collection.
 
         Parameters:
-            entry_points: Entry points to add to the collection.
+            entry_points (Iterable[EntryPointStrategy]): Entry points to add to the collection.
 
         """
         self._entry_points |= set(entry_points)
@@ -316,7 +316,7 @@ class EntryPointStrategyCollection(abc.Collection):
         """Remove entry points from the collection.
 
         Parameters:
-            entry_points: Entry points to remove from the collection.
+            entry_points (Iterable[EntryPointStrategy]): Entry points to remove from the collection.
 
         """
         self._entry_points -= set(entry_points)
@@ -325,7 +325,7 @@ class EntryPointStrategyCollection(abc.Collection):
         """Exclusively add entry points to the collection.
 
         Parameters:
-            entry_points: Entry points to add to the collection.
+            entry_points (Iterable[EntryPointStrategy]): Entry points to add to the collection.
 
         Raises:
             KeyError: If an entry point to be added already exists in the collection.
@@ -502,14 +502,13 @@ def get_strategy_entry_points(
         ) from exc
 
     collection = EntryPointStrategyCollection()
-    for group, oteapi_entry_points in get_entry_points().items():
-        if group.startswith("oteapi.") and group[len("oteapi.") :] == str(
-            strategy_type.value
-        ):
-            if enforce_uniqueness:
-                collection.exclusive_add(
-                    *(EntryPointStrategy(_) for _ in oteapi_entry_points)
-                )
-            else:
-                collection.add(*(EntryPointStrategy(_) for _ in oteapi_entry_points))
+    oteapi_entry_points = sorted(
+        set(get_entry_points().get(f"oteapi.{strategy_type.value}", []))
+    )
+
+    if enforce_uniqueness:
+        collection.exclusive_add(*(EntryPointStrategy(_) for _ in oteapi_entry_points))
+    else:
+        collection.add(*(EntryPointStrategy(_) for _ in oteapi_entry_points))
+
     return collection
